@@ -3,5 +3,6 @@ from chinus_tools.files import json, yaml
 from chinus_tools.pprint import pprint
 from chinus_tools.terminals import get_project_root, clear_screen
 from chinus_tools.dicts import deep_get
+from chinus_tools.yamls import YmlRenderer
 
-__all__ = ['Enum', 'json', 'yaml', 'pprint', 'get_project_root', 'clear_screen', 'deep_get']
+__all__ = ['Enum', 'json', 'yaml', 'pprint', 'get_project_root', 'clear_screen', 'deep_get', 'YmlRenderer']
